summaryrefslogtreecommitdiffstats
path: root/petascope/src/petascope/wcs
diff options
context:
space:
mode:
Diffstat (limited to 'petascope/src/petascope/wcs')
-rw-r--r--petascope/src/petascope/wcs/server/WcsServer.java25
-rw-r--r--petascope/src/petascope/wcs/server/core/TimeString.java43
-rw-r--r--petascope/src/petascope/wcs/server/core/convertGetCoverage.java25
-rw-r--r--petascope/src/petascope/wcs/server/core/executeDescribeCoverage.java25
-rw-r--r--petascope/src/petascope/wcs/server/core/executeGetCapabilities.java25
-rw-r--r--petascope/src/petascope/wcs/server/exceptions/ActionNotSupportedException.java25
-rw-r--r--petascope/src/petascope/wcs/server/exceptions/BadResponseHandlerException.java25
-rw-r--r--petascope/src/petascope/wcs/server/exceptions/InputOutputException.java25
-rw-r--r--petascope/src/petascope/wcs/server/exceptions/InternalComponentException.java25
-rw-r--r--petascope/src/petascope/wcs/server/exceptions/InternalSqlException.java25
-rw-r--r--petascope/src/petascope/wcs/server/exceptions/InvalidParameterValueException.java25
-rw-r--r--petascope/src/petascope/wcs/server/exceptions/InvalidPropertyValueException.java25
-rw-r--r--petascope/src/petascope/wcs/server/exceptions/InvalidRequestException.java25
-rw-r--r--petascope/src/petascope/wcs/server/exceptions/InvalidServiceConfigurationException.java25
-rw-r--r--petascope/src/petascope/wcs/server/exceptions/InvalidTemporalMetadataException.java25
-rw-r--r--petascope/src/petascope/wcs/server/exceptions/MaliciousQueryException.java25
-rw-r--r--petascope/src/petascope/wcs/server/exceptions/MissingParameterValueException.java25
-rw-r--r--petascope/src/petascope/wcs/server/exceptions/MultiBandImagesNotSupportedException.java25
-rw-r--r--petascope/src/petascope/wcs/server/exceptions/NoApplicableCodeException.java25
-rw-r--r--petascope/src/petascope/wcs/server/exceptions/NodeParsingNotImplementedException.java25
-rw-r--r--petascope/src/petascope/wcs/server/exceptions/NotEnoughStorageException.java25
-rw-r--r--petascope/src/petascope/wcs/server/exceptions/RasdamanRequestFailedException.java25
-rw-r--r--petascope/src/petascope/wcs/server/exceptions/RasdamanUnavailableException.java25
-rw-r--r--petascope/src/petascope/wcs/server/exceptions/ServletConnectionException.java25
-rw-r--r--petascope/src/petascope/wcs/server/exceptions/UnsupportedCombinationException.java25
-rw-r--r--petascope/src/petascope/wcs/server/exceptions/WCSException.java25
-rw-r--r--petascope/src/petascope/wcs/server/exceptions/WcsRuntimeException.java25
-rw-r--r--petascope/src/petascope/wcs/server/exceptions/XmlNotValidException.java25
-rw-r--r--petascope/src/petascope/wcs/server/exceptions/XmlStructuresException.java25
29 files changed, 386 insertions, 357 deletions
diff --git a/petascope/src/petascope/wcs/server/core/TimeString.java b/petascope/src/petascope/wcs/server/core/TimeString.java
index 668614e..6e5d04f 100644
--- a/petascope/src/petascope/wcs/server/core/TimeString.java
+++ b/petascope/src/petascope/wcs/server/core/TimeString.java
@@ -1,24 +1,25 @@
-/*
- * This file is part of PetaScope.
- *
- * PetaScope is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License as
- * published by the Free Software Foundation, either version 3 of
- * the License, or (at your option) any later version.
- *
- * PetaScope is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with PetaScope. If not, see <http://www.gnu.org/licenses/>.
- *
- * For more information please see <http://www.PetaScope.org>
- * or contact Peter Baumann via <baumann@rasdaman.com>.
- *
- * Copyright 2009 Jacobs University Bremen, Peter Baumann.
- */
+/*
+ * This file is part of rasdaman community.
+ *
+ * Rasdaman community is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ *
+ * Rasdaman community is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with rasdaman community. If not, see <http://www.gnu.org/licenses/>.
+ *
+ * Copyright 2003, 2004, 2005, 2006, 2007, 2008, 2009 Peter Baumann /
+ rasdaman GmbH.
+ *
+ * For more information please see <http://www.rasdaman.org>
+ * or contact Peter Baumann via <baumann@rasdaman.com>.
+ */
package petascope.wcs.server.core;
//~--- non-JDK imports --------------------------------------------------------
diff --git a/petascope/src/petascope/wcs/server/WcsServer.java b/petascope/src/petascope/wcs/server/WcsServer.java
index 1918950..fddb549 100644
--- a/petascope/src/petascope/wcs/server/WcsServer.java
+++ b/petascope/src/petascope/wcs/server/WcsServer.java
@@ -1,23 +1,24 @@
/*
- * This file is part of PetaScope.
+ * This file is part of rasdaman community.
*
* PetaScope is free software: you can redistribute it and/or modify
* it under the terms of the GNU Lesser General Public License as
* published by the Free Software Foundation, either version 3 of
* the License, or (at your option) any later version.
*
* PetaScope is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU Lesser General Public License for more details.
+ * GNU General Public License for more details.
*
- * You should have received a copy of the GNU Lesser General Public
- * License along with PetaScope. If not, see <http://www.gnu.org/licenses/>.
+ * You should have received a copy of the GNU General Public License
+ * along with rasdaman community. If not, see <http://www.gnu.org/licenses/>.
*
- * For more information please see <http://www.PetaScope.org>
- * or contact Peter Baumann via <baumann@rasdaman.com>.
+ * Copyright 2003, 2004, 2005, 2006, 2007, 2008, 2009 Peter Baumann /
+ rasdaman GmbH.
*
- * Copyright 2009 Jacobs University Bremen, Peter Baumann.
+ * For more information please see <http://www.rasdaman.org>
+ * or contact Peter Baumann via <baumann@rasdaman.com>.
*/
package petascope.wcs.server;
@@ -1,23 +1,24 @@
*
- * PetaScope is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License as
- * published by the Free Software Foundation, either version 3 of
- * the License, or (at your option) any later version.
+ * Rasdaman community is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
*
@@ -1,23 +1,24 @@
*
- * PetaScope is distributed in the hope that it will be useful,
+ * Rasdaman community is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
diff --git a/petascope/src/petascope/wcs/server/core/convertGetCoverage.java b/petascope/src/petascope/wcs/server/core/convertGetCoverage.java
index 7d4a951..92262e6 100644
--- a/petascope/src/petascope/wcs/server/core/convertGetCoverage.java
+++ b/petascope/src/petascope/wcs/server/core/convertGetCoverage.java
@@ -1,23 +1,24 @@
/*
- * This file is part of PetaScope.
+ * This file is part of rasdaman community.
*
* PetaScope is free software: you can redistribute it and/or modify
* it under the terms of the GNU Lesser General Public License as
* published by the Free Software Foundation, either version 3 of
* the License, or (at your option) any later version.
*
* PetaScope is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU Lesser General Public License for more details.
+ * GNU General Public License for more details.
*
- * You should have received a copy of the GNU Lesser General Public
- * License along with PetaScope. If not, see <http://www.gnu.org/licenses/>.
+ * You should have received a copy of the GNU General Public License
+ * along with rasdaman community. If not, see <http://www.gnu.org/licenses/>.
*
- * For more information please see <http://www.PetaScope.org>
- * or contact Peter Baumann via <baumann@rasdaman.com>.
+ * Copyright 2003, 2004, 2005, 2006, 2007, 2008, 2009 Peter Baumann /
+ rasdaman GmbH.
*
- * Copyright 2009 Jacobs University Bremen, Peter Baumann.
+ * For more information please see <http://www.rasdaman.org>
+ * or contact Peter Baumann via <baumann@rasdaman.com>.
*/
package petascope.wcs.server.core;
@@ -1,23 +1,24 @@
*
- * PetaScope is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License as
- * published by the Free Software Foundation, either version 3 of
- * the License, or (at your option) any later version.
+ * Rasdaman community is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
*
@@ -1,23 +1,24 @@
*
- * PetaScope is distributed in the hope that it will be useful,
+ * Rasdaman community is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
diff --git a/petascope/src/petascope/wcs/server/core/executeDescribeCoverage.java b/petascope/src/petascope/wcs/server/core/executeDescribeCoverage.java
index 6df74a8..1a7f882 100644
--- a/petascope/src/petascope/wcs/server/core/executeDescribeCoverage.java
+++ b/petascope/src/petascope/wcs/server/core/executeDescribeCoverage.java
@@ -1,23 +1,24 @@
/*
- * This file is part of PetaScope.
+ * This file is part of rasdaman community.
*
* PetaScope is free software: you can redistribute it and/or modify
* it under the terms of the GNU Lesser General Public License as
* published by the Free Software Foundation, either version 3 of
* the License, or (at your option) any later version.
*
* PetaScope is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU Lesser General Public License for more details.
+ * GNU General Public License for more details.
*
- * You should have received a copy of the GNU Lesser General Public
- * License along with PetaScope. If not, see <http://www.gnu.org/licenses/>.
+ * You should have received a copy of the GNU General Public License
+ * along with rasdaman community. If not, see <http://www.gnu.org/licenses/>.
*
- * For more information please see <http://www.PetaScope.org>
- * or contact Peter Baumann via <baumann@rasdaman.com>.
+ * Copyright 2003, 2004, 2005, 2006, 2007, 2008, 2009 Peter Baumann /
+ rasdaman GmbH.
*
- * Copyright 2009 Jacobs University Bremen, Peter Baumann.
+ * For more information please see <http://www.rasdaman.org>
+ * or contact Peter Baumann via <baumann@rasdaman.com>.
*/
package petascope.wcs.server.core;
@@ -1,23 +1,24 @@
*
- * PetaScope is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License as
- * published by the Free Software Foundation, either version 3 of
- * the License, or (at your option) any later version.
+ * Rasdaman community is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
*
@@ -1,23 +1,24 @@
*
- * PetaScope is distributed in the hope that it will be useful,
+ * Rasdaman community is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
diff --git a/petascope/src/petascope/wcs/server/core/executeGetCapabilities.java b/petascope/src/petascope/wcs/server/core/executeGetCapabilities.java
index aaa84c0..846f2c8 100644
--- a/petascope/src/petascope/wcs/server/core/executeGetCapabilities.java
+++ b/petascope/src/petascope/wcs/server/core/executeGetCapabilities.java
@@ -1,23 +1,24 @@
/*
- * This file is part of PetaScope.
+ * This file is part of rasdaman community.
*
* PetaScope is free software: you can redistribute it and/or modify
* it under the terms of the GNU Lesser General Public License as
* published by the Free Software Foundation, either version 3 of
* the License, or (at your option) any later version.
*
* PetaScope is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU Lesser General Public License for more details.
+ * GNU General Public License for more details.
*
- * You should have received a copy of the GNU Lesser General Public
- * License along with PetaScope. If not, see <http://www.gnu.org/licenses/>.
+ * You should have received a copy of the GNU General Public License
+ * along with rasdaman community. If not, see <http://www.gnu.org/licenses/>.
*
- * For more information please see <http://www.PetaScope.org>
- * or contact Peter Baumann via <baumann@rasdaman.com>.
+ * Copyright 2003, 2004, 2005, 2006, 2007, 2008, 2009 Peter Baumann /
+ rasdaman GmbH.
*
- * Copyright 2009 Jacobs University Bremen, Peter Baumann.
+ * For more information please see <http://www.rasdaman.org>
+ * or contact Peter Baumann via <baumann@rasdaman.com>.
*/
package petascope.wcs.server.core;
@@ -1,23 +1,24 @@
*
- * PetaScope is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License as
- * published by the Free Software Foundation, either version 3 of
- * the License, or (at your option) any later version.
+ * Rasdaman community is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
*
@@ -1,23 +1,24 @@
*
- * PetaScope is distributed in the hope that it will be useful,
+ * Rasdaman community is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
diff --git a/petascope/src/petascope/wcs/server/exceptions/ActionNotSupportedException.java b/petascope/src/petascope/wcs/server/exceptions/ActionNotSupportedException.java
index 70cb368..3211bb6 100644
--- a/petascope/src/petascope/wcs/server/exceptions/ActionNotSupportedException.java
+++ b/petascope/src/petascope/wcs/server/exceptions/ActionNotSupportedException.java
@@ -1,23 +1,24 @@
/*
- * This file is part of PetaScope.
+ * This file is part of rasdaman community.
*
* PetaScope is free software: you can redistribute it and/or modify
* it under the terms of the GNU Lesser General Public License as
* published by the Free Software Foundation, either version 3 of
* the License, or (at your option) any later version.
*
* PetaScope is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU Lesser General Public License for more details.
+ * GNU General Public License for more details.
*
- * You should have received a copy of the GNU Lesser General Public
- * License along with PetaScope. If not, see <http://www.gnu.org/licenses/>.
+ * You should have received a copy of the GNU General Public License
+ * along with rasdaman community. If not, see <http://www.gnu.org/licenses/>.
*
- * For more information please see <http://www.PetaScope.org>
- * or contact Peter Baumann via <baumann@rasdaman.com>.
+ * Copyright 2003, 2004, 2005, 2006, 2007, 2008, 2009 Peter Baumann /
+ rasdaman GmbH.
*
- * Copyright 2009 Jacobs University Bremen, Peter Baumann.
+ * For more information please see <http://www.rasdaman.org>
+ * or contact Peter Baumann via <baumann@rasdaman.com>.
*/
package petascope.wcs.server.exceptions;
@@ -1,23 +1,24 @@
*
- * PetaScope is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License as
- * published by the Free Software Foundation, either version 3 of
- * the License, or (at your option) any later version.
+ * Rasdaman community is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
*
@@ -1,23 +1,24 @@
*
- * PetaScope is distributed in the hope that it will be useful,
+ * Rasdaman community is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
diff --git a/petascope/src/petascope/wcs/server/exceptions/BadResponseHandlerException.java b/petascope/src/petascope/wcs/server/exceptions/BadResponseHandlerException.java
index 118eda1..5fa186c 100644
--- a/petascope/src/petascope/wcs/server/exceptions/BadResponseHandlerException.java
+++ b/petascope/src/petascope/wcs/server/exceptions/BadResponseHandlerException.java
@@ -1,23 +1,24 @@
/*
- * This file is part of PetaScope.
+ * This file is part of rasdaman community.
*
* PetaScope is free software: you can redistribute it and/or modify
* it under the terms of the GNU Lesser General Public License as
* published by the Free Software Foundation, either version 3 of
* the License, or (at your option) any later version.
*
* PetaScope is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU Lesser General Public License for more details.
+ * GNU General Public License for more details.
*
- * You should have received a copy of the GNU Lesser General Public
- * License along with PetaScope. If not, see <http://www.gnu.org/licenses/>.
+ * You should have received a copy of the GNU General Public License
+ * along with rasdaman community. If not, see <http://www.gnu.org/licenses/>.
*
- * For more information please see <http://www.PetaScope.org>
- * or contact Peter Baumann via <baumann@rasdaman.com>.
+ * Copyright 2003, 2004, 2005, 2006, 2007, 2008, 2009 Peter Baumann /
+ rasdaman GmbH.
*
- * Copyright 2009 Jacobs University Bremen, Peter Baumann.
+ * For more information please see <http://www.rasdaman.org>
+ * or contact Peter Baumann via <baumann@rasdaman.com>.
*/
package petascope.wcs.server.exceptions;
@@ -1,23 +1,24 @@
*
- * PetaScope is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License as
- * published by the Free Software Foundation, either version 3 of
- * the License, or (at your option) any later version.
+ * Rasdaman community is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
*
@@ -1,23 +1,24 @@
*
- * PetaScope is distributed in the hope that it will be useful,
+ * Rasdaman community is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
diff --git a/petascope/src/petascope/wcs/server/exceptions/InputOutputException.java b/petascope/src/petascope/wcs/server/exceptions/InputOutputException.java
index 610f1d6..f3a8667 100644
--- a/petascope/src/petascope/wcs/server/exceptions/InputOutputException.java
+++ b/petascope/src/petascope/wcs/server/exceptions/InputOutputException.java
@@ -1,23 +1,24 @@
/*
- * This file is part of PetaScope.
+ * This file is part of rasdaman community.
*
* PetaScope is free software: you can redistribute it and/or modify
* it under the terms of the GNU Lesser General Public License as
* published by the Free Software Foundation, either version 3 of
* the License, or (at your option) any later version.
*
* PetaScope is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU Lesser General Public License for more details.
+ * GNU General Public License for more details.
*
- * You should have received a copy of the GNU Lesser General Public
- * License along with PetaScope. If not, see <http://www.gnu.org/licenses/>.
+ * You should have received a copy of the GNU General Public License
+ * along with rasdaman community. If not, see <http://www.gnu.org/licenses/>.
*
- * For more information please see <http://www.PetaScope.org>
- * or contact Peter Baumann via <baumann@rasdaman.com>.
+ * Copyright 2003, 2004, 2005, 2006, 2007, 2008, 2009 Peter Baumann /
+ rasdaman GmbH.
*
- * Copyright 2009 Jacobs University Bremen, Peter Baumann.
+ * For more information please see <http://www.rasdaman.org>
+ * or contact Peter Baumann via <baumann@rasdaman.com>.
*/
package petascope.wcs.server.exceptions;
@@ -1,23 +1,24 @@
*
- * PetaScope is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License as
- * published by the Free Software Foundation, either version 3 of
- * the License, or (at your option) any later version.
+ * Rasdaman community is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
*
@@ -1,23 +1,24 @@
*
- * PetaScope is distributed in the hope that it will be useful,
+ * Rasdaman community is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
diff --git a/petascope/src/petascope/wcs/server/exceptions/InternalComponentException.java b/petascope/src/petascope/wcs/server/exceptions/InternalComponentException.java
index 3680dae..367ad3e 100644
--- a/petascope/src/petascope/wcs/server/exceptions/InternalComponentException.java
+++ b/petascope/src/petascope/wcs/server/exceptions/InternalComponentException.java
@@ -1,23 +1,24 @@
/*
- * This file is part of PetaScope.
+ * This file is part of rasdaman community.
*
* PetaScope is free software: you can redistribute it and/or modify
* it under the terms of the GNU Lesser General Public License as
* published by the Free Software Foundation, either version 3 of
* the License, or (at your option) any later version.
*
* PetaScope is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU Lesser General Public License for more details.
+ * GNU General Public License for more details.
*
- * You should have received a copy of the GNU Lesser General Public
- * License along with PetaScope. If not, see <http://www.gnu.org/licenses/>.
+ * You should have received a copy of the GNU General Public License
+ * along with rasdaman community. If not, see <http://www.gnu.org/licenses/>.
*
- * For more information please see <http://www.PetaScope.org>
- * or contact Peter Baumann via <baumann@rasdaman.com>.
+ * Copyright 2003, 2004, 2005, 2006, 2007, 2008, 2009 Peter Baumann /
+ rasdaman GmbH.
*
- * Copyright 2009 Jacobs University Bremen, Peter Baumann.
+ * For more information please see <http://www.rasdaman.org>
+ * or contact Peter Baumann via <baumann@rasdaman.com>.
*/
package petascope.wcs.server.exceptions;
@@ -1,23 +1,24 @@
*
- * PetaScope is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License as
- * published by the Free Software Foundation, either version 3 of
- * the License, or (at your option) any later version.
+ * Rasdaman community is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
*
@@ -1,23 +1,24 @@
*
- * PetaScope is distributed in the hope that it will be useful,
+ * Rasdaman community is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
diff --git a/petascope/src/petascope/wcs/server/exceptions/InternalSqlException.java b/petascope/src/petascope/wcs/server/exceptions/InternalSqlException.java
index 1ae95ce..d415864 100644
--- a/petascope/src/petascope/wcs/server/exceptions/InternalSqlException.java
+++ b/petascope/src/petascope/wcs/server/exceptions/InternalSqlException.java
@@ -1,23 +1,24 @@
/*
- * This file is part of PetaScope.
+ * This file is part of rasdaman community.
*
* PetaScope is free software: you can redistribute it and/or modify
* it under the terms of the GNU Lesser General Public License as
* published by the Free Software Foundation, either version 3 of
* the License, or (at your option) any later version.
*
* PetaScope is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU Lesser General Public License for more details.
+ * GNU General Public License for more details.
*
- * You should have received a copy of the GNU Lesser General Public
- * License along with PetaScope. If not, see <http://www.gnu.org/licenses/>.
+ * You should have received a copy of the GNU General Public License
+ * along with rasdaman community. If not, see <http://www.gnu.org/licenses/>.
*
- * For more information please see <http://www.PetaScope.org>
- * or contact Peter Baumann via <baumann@rasdaman.com>.
+ * Copyright 2003, 2004, 2005, 2006, 2007, 2008, 2009 Peter Baumann /
+ rasdaman GmbH.
*
- * Copyright 2009 Jacobs University Bremen, Peter Baumann.
+ * For more information please see <http://www.rasdaman.org>
+ * or contact Peter Baumann via <baumann@rasdaman.com>.
*/
package petascope.wcs.server.exceptions;
@@ -1,23 +1,24 @@
*
- * PetaScope is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License as
- * published by the Free Software Foundation, either version 3 of
- * the License, or (at your option) any later version.
+ * Rasdaman community is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
*
@@ -1,23 +1,24 @@
*
- * PetaScope is distributed in the hope that it will be useful,
+ * Rasdaman community is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
diff --git a/petascope/src/petascope/wcs/server/exceptions/InvalidParameterValueException.java b/petascope/src/petascope/wcs/server/exceptions/InvalidParameterValueException.java
index ae863c2..5f03a72 100644
--- a/petascope/src/petascope/wcs/server/exceptions/InvalidParameterValueException.java
+++ b/petascope/src/petascope/wcs/server/exceptions/InvalidParameterValueException.java
@@ -1,23 +1,24 @@
/*
- * This file is part of PetaScope.
+ * This file is part of rasdaman community.
*
* PetaScope is free software: you can redistribute it and/or modify
* it under the terms of the GNU Lesser General Public License as
* published by the Free Software Foundation, either version 3 of
* the License, or (at your option) any later version.
*
* PetaScope is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU Lesser General Public License for more details.
+ * GNU General Public License for more details.
*
- * You should have received a copy of the GNU Lesser General Public
- * License along with PetaScope. If not, see <http://www.gnu.org/licenses/>.
+ * You should have received a copy of the GNU General Public License
+ * along with rasdaman community. If not, see <http://www.gnu.org/licenses/>.
*
- * For more information please see <http://www.PetaScope.org>
- * or contact Peter Baumann via <baumann@rasdaman.com>.
+ * Copyright 2003, 2004, 2005, 2006, 2007, 2008, 2009 Peter Baumann /
+ rasdaman GmbH.
*
- * Copyright 2009 Jacobs University Bremen, Peter Baumann.
+ * For more information please see <http://www.rasdaman.org>
+ * or contact Peter Baumann via <baumann@rasdaman.com>.
*/
package petascope.wcs.server.exceptions;
@@ -1,23 +1,24 @@
*
- * PetaScope is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License as
- * published by the Free Software Foundation, either version 3 of
- * the License, or (at your option) any later version.
+ * Rasdaman community is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
*
@@ -1,23 +1,24 @@
*
- * PetaScope is distributed in the hope that it will be useful,
+ * Rasdaman community is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
diff --git a/petascope/src/petascope/wcs/server/exceptions/InvalidPropertyValueException.java b/petascope/src/petascope/wcs/server/exceptions/InvalidPropertyValueException.java
index a324837..9c036b3 100644
--- a/petascope/src/petascope/wcs/server/exceptions/InvalidPropertyValueException.java
+++ b/petascope/src/petascope/wcs/server/exceptions/InvalidPropertyValueException.java
@@ -1,23 +1,24 @@
/*
- * This file is part of PetaScope.
+ * This file is part of rasdaman community.
*
* PetaScope is free software: you can redistribute it and/or modify
* it under the terms of the GNU Lesser General Public License as
* published by the Free Software Foundation, either version 3 of
* the License, or (at your option) any later version.
*
* PetaScope is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU Lesser General Public License for more details.
+ * GNU General Public License for more details.
*
- * You should have received a copy of the GNU Lesser General Public
- * License along with PetaScope. If not, see <http://www.gnu.org/licenses/>.
+ * You should have received a copy of the GNU General Public License
+ * along with rasdaman community. If not, see <http://www.gnu.org/licenses/>.
*
- * For more information please see <http://www.PetaScope.org>
- * or contact Peter Baumann via <baumann@rasdaman.com>.
+ * Copyright 2003, 2004, 2005, 2006, 2007, 2008, 2009 Peter Baumann /
+ rasdaman GmbH.
*
- * Copyright 2009 Jacobs University Bremen, Peter Baumann.
+ * For more information please see <http://www.rasdaman.org>
+ * or contact Peter Baumann via <baumann@rasdaman.com>.
*/
package petascope.wcs.server.exceptions;
@@ -1,23 +1,24 @@
*
- * PetaScope is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License as
- * published by the Free Software Foundation, either version 3 of
- * the License, or (at your option) any later version.
+ * Rasdaman community is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
*
@@ -1,23 +1,24 @@
*
- * PetaScope is distributed in the hope that it will be useful,
+ * Rasdaman community is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
diff --git a/petascope/src/petascope/wcs/server/exceptions/InvalidRequestException.java b/petascope/src/petascope/wcs/server/exceptions/InvalidRequestException.java
index 9c17239..e357684 100644
--- a/petascope/src/petascope/wcs/server/exceptions/InvalidRequestException.java
+++ b/petascope/src/petascope/wcs/server/exceptions/InvalidRequestException.java
@@ -1,23 +1,24 @@
/*
- * This file is part of PetaScope.
+ * This file is part of rasdaman community.
*
* PetaScope is free software: you can redistribute it and/or modify
* it under the terms of the GNU Lesser General Public License as
* published by the Free Software Foundation, either version 3 of
* the License, or (at your option) any later version.
*
* PetaScope is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU Lesser General Public License for more details.
+ * GNU General Public License for more details.
*
- * You should have received a copy of the GNU Lesser General Public
- * License along with PetaScope. If not, see <http://www.gnu.org/licenses/>.
+ * You should have received a copy of the GNU General Public License
+ * along with rasdaman community. If not, see <http://www.gnu.org/licenses/>.
*
- * For more information please see <http://www.PetaScope.org>
- * or contact Peter Baumann via <baumann@rasdaman.com>.
+ * Copyright 2003, 2004, 2005, 2006, 2007, 2008, 2009 Peter Baumann /
+ rasdaman GmbH.
*
- * Copyright 2009 Jacobs University Bremen, Peter Baumann.
+ * For more information please see <http://www.rasdaman.org>
+ * or contact Peter Baumann via <baumann@rasdaman.com>.
*/
package petascope.wcs.server.exceptions;
@@ -1,23 +1,24 @@
*
- * PetaScope is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License as
- * published by the Free Software Foundation, either version 3 of
- * the License, or (at your option) any later version.
+ * Rasdaman community is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
*
@@ -1,23 +1,24 @@
*
- * PetaScope is distributed in the hope that it will be useful,
+ * Rasdaman community is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
diff --git a/petascope/src/petascope/wcs/server/exceptions/InvalidServiceConfigurationException.java b/petascope/src/petascope/wcs/server/exceptions/InvalidServiceConfigurationException.java
index 41b2241..4f84673 100644
--- a/petascope/src/petascope/wcs/server/exceptions/InvalidServiceConfigurationException.java
+++ b/petascope/src/petascope/wcs/server/exceptions/InvalidServiceConfigurationException.java
@@ -1,23 +1,24 @@
/*
- * This file is part of PetaScope.
+ * This file is part of rasdaman community.
*
* PetaScope is free software: you can redistribute it and/or modify
* it under the terms of the GNU Lesser General Public License as
* published by the Free Software Foundation, either version 3 of
* the License, or (at your option) any later version.
*
* PetaScope is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU Lesser General Public License for more details.
+ * GNU General Public License for more details.
*
- * You should have received a copy of the GNU Lesser General Public
- * License along with PetaScope. If not, see <http://www.gnu.org/licenses/>.
+ * You should have received a copy of the GNU General Public License
+ * along with rasdaman community. If not, see <http://www.gnu.org/licenses/>.
*
- * For more information please see <http://www.PetaScope.org>
- * or contact Peter Baumann via <baumann@rasdaman.com>.
+ * Copyright 2003, 2004, 2005, 2006, 2007, 2008, 2009 Peter Baumann /
+ rasdaman GmbH.
*
- * Copyright 2009 Jacobs University Bremen, Peter Baumann.
+ * For more information please see <http://www.rasdaman.org>
+ * or contact Peter Baumann via <baumann@rasdaman.com>.
*/
package petascope.wcs.server.exceptions;
@@ -1,23 +1,24 @@
*
- * PetaScope is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License as
- * published by the Free Software Foundation, either version 3 of
- * the License, or (at your option) any later version.
+ * Rasdaman community is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
*
@@ -1,23 +1,24 @@
*
- * PetaScope is distributed in the hope that it will be useful,
+ * Rasdaman community is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
diff --git a/petascope/src/petascope/wcs/server/exceptions/InvalidTemporalMetadataException.java b/petascope/src/petascope/wcs/server/exceptions/InvalidTemporalMetadataException.java
index d075084..1ad11de 100644
--- a/petascope/src/petascope/wcs/server/exceptions/InvalidTemporalMetadataException.java
+++ b/petascope/src/petascope/wcs/server/exceptions/InvalidTemporalMetadataException.java
@@ -1,23 +1,24 @@
/*
- * This file is part of PetaScope.
+ * This file is part of rasdaman community.
*
* PetaScope is free software: you can redistribute it and/or modify
* it under the terms of the GNU Lesser General Public License as
* published by the Free Software Foundation, either version 3 of
* the License, or (at your option) any later version.
*
* PetaScope is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU Lesser General Public License for more details.
+ * GNU General Public License for more details.
*
- * You should have received a copy of the GNU Lesser General Public
- * License along with PetaScope. If not, see <http://www.gnu.org/licenses/>.
+ * You should have received a copy of the GNU General Public License
+ * along with rasdaman community. If not, see <http://www.gnu.org/licenses/>.
*
- * For more information please see <http://www.PetaScope.org>
- * or contact Peter Baumann via <baumann@rasdaman.com>.
+ * Copyright 2003, 2004, 2005, 2006, 2007, 2008, 2009 Peter Baumann /
+ rasdaman GmbH.
*
- * Copyright 2009 Jacobs University Bremen, Peter Baumann.
+ * For more information please see <http://www.rasdaman.org>
+ * or contact Peter Baumann via <baumann@rasdaman.com>.
*/
package petascope.wcs.server.exceptions;
@@ -1,23 +1,24 @@
*
- * PetaScope is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License as
- * published by the Free Software Foundation, either version 3 of
- * the License, or (at your option) any later version.
+ * Rasdaman community is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
*
@@ -1,23 +1,24 @@
*
- * PetaScope is distributed in the hope that it will be useful,
+ * Rasdaman community is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
diff --git a/petascope/src/petascope/wcs/server/exceptions/MaliciousQueryException.java b/petascope/src/petascope/wcs/server/exceptions/MaliciousQueryException.java
index 22f7897..bc00baa 100644
--- a/petascope/src/petascope/wcs/server/exceptions/MaliciousQueryException.java
+++ b/petascope/src/petascope/wcs/server/exceptions/MaliciousQueryException.java
@@ -1,23 +1,24 @@
/*
- * This file is part of PetaScope.
+ * This file is part of rasdaman community.
*
* PetaScope is free software: you can redistribute it and/or modify
* it under the terms of the GNU Lesser General Public License as
* published by the Free Software Foundation, either version 3 of
* the License, or (at your option) any later version.
*
* PetaScope is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU Lesser General Public License for more details.
+ * GNU General Public License for more details.
*
- * You should have received a copy of the GNU Lesser General Public
- * License along with PetaScope. If not, see <http://www.gnu.org/licenses/>.
+ * You should have received a copy of the GNU General Public License
+ * along with rasdaman community. If not, see <http://www.gnu.org/licenses/>.
*
- * For more information please see <http://www.PetaScope.org>
- * or contact Peter Baumann via <baumann@rasdaman.com>.
+ * Copyright 2003, 2004, 2005, 2006, 2007, 2008, 2009 Peter Baumann /
+ rasdaman GmbH.
*
- * Copyright 2009 Jacobs University Bremen, Peter Baumann.
+ * For more information please see <http://www.rasdaman.org>
+ * or contact Peter Baumann via <baumann@rasdaman.com>.
*/
package petascope.wcs.server.exceptions;
@@ -1,23 +1,24 @@
*
- * PetaScope is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License as
- * published by the Free Software Foundation, either version 3 of
- * the License, or (at your option) any later version.
+ * Rasdaman community is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
*
@@ -1,23 +1,24 @@
*
- * PetaScope is distributed in the hope that it will be useful,
+ * Rasdaman community is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
diff --git a/petascope/src/petascope/wcs/server/exceptions/MissingParameterValueException.java b/petascope/src/petascope/wcs/server/exceptions/MissingParameterValueException.java
index 7ff6aa4..deb4390 100644
--- a/petascope/src/petascope/wcs/server/exceptions/MissingParameterValueException.java
+++ b/petascope/src/petascope/wcs/server/exceptions/MissingParameterValueException.java
@@ -1,23 +1,24 @@
/*
- * This file is part of PetaScope.
+ * This file is part of rasdaman community.
*
* PetaScope is free software: you can redistribute it and/or modify
* it under the terms of the GNU Lesser General Public License as
* published by the Free Software Foundation, either version 3 of
* the License, or (at your option) any later version.
*
* PetaScope is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU Lesser General Public License for more details.
+ * GNU General Public License for more details.
*
- * You should have received a copy of the GNU Lesser General Public
- * License along with PetaScope. If not, see <http://www.gnu.org/licenses/>.
+ * You should have received a copy of the GNU General Public License
+ * along with rasdaman community. If not, see <http://www.gnu.org/licenses/>.
*
- * For more information please see <http://www.PetaScope.org>
- * or contact Peter Baumann via <baumann@rasdaman.com>.
+ * Copyright 2003, 2004, 2005, 2006, 2007, 2008, 2009 Peter Baumann /
+ rasdaman GmbH.
*
- * Copyright 2009 Jacobs University Bremen, Peter Baumann.
+ * For more information please see <http://www.rasdaman.org>
+ * or contact Peter Baumann via <baumann@rasdaman.com>.
*/
package petascope.wcs.server.exceptions;
@@ -1,23 +1,24 @@
*
- * PetaScope is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License as
- * published by the Free Software Foundation, either version 3 of
- * the License, or (at your option) any later version.
+ * Rasdaman community is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
*
@@ -1,23 +1,24 @@
*
- * PetaScope is distributed in the hope that it will be useful,
+ * Rasdaman community is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
diff --git a/petascope/src/petascope/wcs/server/exceptions/MultiBandImagesNotSupportedException.java b/petascope/src/petascope/wcs/server/exceptions/MultiBandImagesNotSupportedException.java
index e0cff7a..63a9919 100644
--- a/petascope/src/petascope/wcs/server/exceptions/MultiBandImagesNotSupportedException.java
+++ b/petascope/src/petascope/wcs/server/exceptions/MultiBandImagesNotSupportedException.java
@@ -1,23 +1,24 @@
/*
- * This file is part of PetaScope.
+ * This file is part of rasdaman community.
*
* PetaScope is free software: you can redistribute it and/or modify
* it under the terms of the GNU Lesser General Public License as
* published by the Free Software Foundation, either version 3 of
* the License, or (at your option) any later version.
*
* PetaScope is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU Lesser General Public License for more details.
+ * GNU General Public License for more details.
*
- * You should have received a copy of the GNU Lesser General Public
- * License along with PetaScope. If not, see <http://www.gnu.org/licenses/>.
+ * You should have received a copy of the GNU General Public License
+ * along with rasdaman community. If not, see <http://www.gnu.org/licenses/>.
*
- * For more information please see <http://www.PetaScope.org>
- * or contact Peter Baumann via <baumann@rasdaman.com>.
+ * Copyright 2003, 2004, 2005, 2006, 2007, 2008, 2009 Peter Baumann /
+ rasdaman GmbH.
*
- * Copyright 2009 Jacobs University Bremen, Peter Baumann.
+ * For more information please see <http://www.rasdaman.org>
+ * or contact Peter Baumann via <baumann@rasdaman.com>.
*/
package petascope.wcs.server.exceptions;
@@ -1,23 +1,24 @@
*
- * PetaScope is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License as
- * published by the Free Software Foundation, either version 3 of
- * the License, or (at your option) any later version.
+ * Rasdaman community is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
*
@@ -1,23 +1,24 @@
*
- * PetaScope is distributed in the hope that it will be useful,
+ * Rasdaman community is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
diff --git a/petascope/src/petascope/wcs/server/exceptions/NoApplicableCodeException.java b/petascope/src/petascope/wcs/server/exceptions/NoApplicableCodeException.java
index 0e23528..0568ece 100644
--- a/petascope/src/petascope/wcs/server/exceptions/NoApplicableCodeException.java
+++ b/petascope/src/petascope/wcs/server/exceptions/NoApplicableCodeException.java
@@ -1,23 +1,24 @@
/*
- * This file is part of PetaScope.
+ * This file is part of rasdaman community.
*
* PetaScope is free software: you can redistribute it and/or modify
* it under the terms of the GNU Lesser General Public License as
* published by the Free Software Foundation, either version 3 of
* the License, or (at your option) any later version.
*
* PetaScope is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU Lesser General Public License for more details.
+ * GNU General Public License for more details.
*
- * You should have received a copy of the GNU Lesser General Public
- * License along with PetaScope. If not, see <http://www.gnu.org/licenses/>.
+ * You should have received a copy of the GNU General Public License
+ * along with rasdaman community. If not, see <http://www.gnu.org/licenses/>.
*
- * For more information please see <http://www.PetaScope.org>
- * or contact Peter Baumann via <baumann@rasdaman.com>.
+ * Copyright 2003, 2004, 2005, 2006, 2007, 2008, 2009 Peter Baumann /
+ rasdaman GmbH.
*
- * Copyright 2009 Jacobs University Bremen, Peter Baumann.
+ * For more information please see <http://www.rasdaman.org>
+ * or contact Peter Baumann via <baumann@rasdaman.com>.
*/
package petascope.wcs.server.exceptions;
@@ -1,23 +1,24 @@
*
- * PetaScope is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License as
- * published by the Free Software Foundation, either version 3 of
- * the License, or (at your option) any later version.
+ * Rasdaman community is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
*
@@ -1,23 +1,24 @@
*
- * PetaScope is distributed in the hope that it will be useful,
+ * Rasdaman community is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
diff --git a/petascope/src/petascope/wcs/server/exceptions/NodeParsingNotImplementedException.java b/petascope/src/petascope/wcs/server/exceptions/NodeParsingNotImplementedException.java
index 5cec9ce..d1e278d 100644
--- a/petascope/src/petascope/wcs/server/exceptions/NodeParsingNotImplementedException.java
+++ b/petascope/src/petascope/wcs/server/exceptions/NodeParsingNotImplementedException.java
@@ -1,23 +1,24 @@
/*
- * This file is part of PetaScope.
+ * This file is part of rasdaman community.
*
* PetaScope is free software: you can redistribute it and/or modify
* it under the terms of the GNU Lesser General Public License as
* published by the Free Software Foundation, either version 3 of
* the License, or (at your option) any later version.
*
* PetaScope is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU Lesser General Public License for more details.
+ * GNU General Public License for more details.
*
- * You should have received a copy of the GNU Lesser General Public
- * License along with PetaScope. If not, see <http://www.gnu.org/licenses/>.
+ * You should have received a copy of the GNU General Public License
+ * along with rasdaman community. If not, see <http://www.gnu.org/licenses/>.
*
- * For more information please see <http://www.PetaScope.org>
- * or contact Peter Baumann via <baumann@rasdaman.com>.
+ * Copyright 2003, 2004, 2005, 2006, 2007, 2008, 2009 Peter Baumann /
+ rasdaman GmbH.
*
- * Copyright 2009 Jacobs University Bremen, Peter Baumann.
+ * For more information please see <http://www.rasdaman.org>
+ * or contact Peter Baumann via <baumann@rasdaman.com>.
*/
package petascope.wcs.server.exceptions;
@@ -1,23 +1,24 @@
*
- * PetaScope is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License as
- * published by the Free Software Foundation, either version 3 of
- * the License, or (at your option) any later version.
+ * Rasdaman community is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
*
@@ -1,23 +1,24 @@
*
- * PetaScope is distributed in the hope that it will be useful,
+ * Rasdaman community is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
diff --git a/petascope/src/petascope/wcs/server/exceptions/NotEnoughStorageException.java b/petascope/src/petascope/wcs/server/exceptions/NotEnoughStorageException.java
index c3f8d25..f1a668a 100644
--- a/petascope/src/petascope/wcs/server/exceptions/NotEnoughStorageException.java
+++ b/petascope/src/petascope/wcs/server/exceptions/NotEnoughStorageException.java
@@ -1,23 +1,24 @@
/*
- * This file is part of PetaScope.
+ * This file is part of rasdaman community.
*
* PetaScope is free software: you can redistribute it and/or modify
* it under the terms of the GNU Lesser General Public License as
* published by the Free Software Foundation, either version 3 of
* the License, or (at your option) any later version.
*
* PetaScope is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU Lesser General Public License for more details.
+ * GNU General Public License for more details.
*
- * You should have received a copy of the GNU Lesser General Public
- * License along with PetaScope. If not, see <http://www.gnu.org/licenses/>.
+ * You should have received a copy of the GNU General Public License
+ * along with rasdaman community. If not, see <http://www.gnu.org/licenses/>.
*
- * For more information please see <http://www.PetaScope.org>
- * or contact Peter Baumann via <baumann@rasdaman.com>.
+ * Copyright 2003, 2004, 2005, 2006, 2007, 2008, 2009 Peter Baumann /
+ rasdaman GmbH.
*
- * Copyright 2009 Jacobs University Bremen, Peter Baumann.
+ * For more information please see <http://www.rasdaman.org>
+ * or contact Peter Baumann via <baumann@rasdaman.com>.
*/
package petascope.wcs.server.exceptions;
@@ -1,23 +1,24 @@
*
- * PetaScope is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License as
- * published by the Free Software Foundation, either version 3 of
- * the License, or (at your option) any later version.
+ * Rasdaman community is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
*
@@ -1,23 +1,24 @@
*
- * PetaScope is distributed in the hope that it will be useful,
+ * Rasdaman community is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
diff --git a/petascope/src/petascope/wcs/server/exceptions/RasdamanRequestFailedException.java b/petascope/src/petascope/wcs/server/exceptions/RasdamanRequestFailedException.java
index 9f42df1..0960247 100644
--- a/petascope/src/petascope/wcs/server/exceptions/RasdamanRequestFailedException.java
+++ b/petascope/src/petascope/wcs/server/exceptions/RasdamanRequestFailedException.java
@@ -1,23 +1,24 @@
/*
- * This file is part of PetaScope.
+ * This file is part of rasdaman community.
*
* PetaScope is free software: you can redistribute it and/or modify
* it under the terms of the GNU Lesser General Public License as
* published by the Free Software Foundation, either version 3 of
* the License, or (at your option) any later version.
*
* PetaScope is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU Lesser General Public License for more details.
+ * GNU General Public License for more details.
*
- * You should have received a copy of the GNU Lesser General Public
- * License along with PetaScope. If not, see <http://www.gnu.org/licenses/>.
+ * You should have received a copy of the GNU General Public License
+ * along with rasdaman community. If not, see <http://www.gnu.org/licenses/>.
*
- * For more information please see <http://www.PetaScope.org>
- * or contact Peter Baumann via <baumann@rasdaman.com>.
+ * Copyright 2003, 2004, 2005, 2006, 2007, 2008, 2009 Peter Baumann /
+ rasdaman GmbH.
*
- * Copyright 2009 Jacobs University Bremen, Peter Baumann.
+ * For more information please see <http://www.rasdaman.org>
+ * or contact Peter Baumann via <baumann@rasdaman.com>.
*/
package petascope.wcs.server.exceptions;
@@ -1,23 +1,24 @@
*
- * PetaScope is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License as
- * published by the Free Software Foundation, either version 3 of
- * the License, or (at your option) any later version.
+ * Rasdaman community is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
*
@@ -1,23 +1,24 @@
*
- * PetaScope is distributed in the hope that it will be useful,
+ * Rasdaman community is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
diff --git a/petascope/src/petascope/wcs/server/exceptions/RasdamanUnavailableException.java b/petascope/src/petascope/wcs/server/exceptions/RasdamanUnavailableException.java
index 6bbb3e3..db700c6 100644
--- a/petascope/src/petascope/wcs/server/exceptions/RasdamanUnavailableException.java
+++ b/petascope/src/petascope/wcs/server/exceptions/RasdamanUnavailableException.java
@@ -1,23 +1,24 @@
/*
- * This file is part of PetaScope.
+ * This file is part of rasdaman community.
*
* PetaScope is free software: you can redistribute it and/or modify
* it under the terms of the GNU Lesser General Public License as
* published by the Free Software Foundation, either version 3 of
* the License, or (at your option) any later version.
*
* PetaScope is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU Lesser General Public License for more details.
+ * GNU General Public License for more details.
*
- * You should have received a copy of the GNU Lesser General Public
- * License along with PetaScope. If not, see <http://www.gnu.org/licenses/>.
+ * You should have received a copy of the GNU General Public License
+ * along with rasdaman community. If not, see <http://www.gnu.org/licenses/>.
*
- * For more information please see <http://www.PetaScope.org>
- * or contact Peter Baumann via <baumann@rasdaman.com>.
+ * Copyright 2003, 2004, 2005, 2006, 2007, 2008, 2009 Peter Baumann /
+ rasdaman GmbH.
*
- * Copyright 2009 Jacobs University Bremen, Peter Baumann.
+ * For more information please see <http://www.rasdaman.org>
+ * or contact Peter Baumann via <baumann@rasdaman.com>.
*/
package petascope.wcs.server.exceptions;
@@ -1,23 +1,24 @@
*
- * PetaScope is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License as
- * published by the Free Software Foundation, either version 3 of
- * the License, or (at your option) any later version.
+ * Rasdaman community is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
*
@@ -1,23 +1,24 @@
*
- * PetaScope is distributed in the hope that it will be useful,
+ * Rasdaman community is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
diff --git a/petascope/src/petascope/wcs/server/exceptions/ServletConnectionException.java b/petascope/src/petascope/wcs/server/exceptions/ServletConnectionException.java
index 05ec45b..d458cd2 100644
--- a/petascope/src/petascope/wcs/server/exceptions/ServletConnectionException.java
+++ b/petascope/src/petascope/wcs/server/exceptions/ServletConnectionException.java
@@ -1,23 +1,24 @@
/*
- * This file is part of PetaScope.
+ * This file is part of rasdaman community.
*
* PetaScope is free software: you can redistribute it and/or modify
* it under the terms of the GNU Lesser General Public License as
* published by the Free Software Foundation, either version 3 of
* the License, or (at your option) any later version.
*
* PetaScope is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU Lesser General Public License for more details.
+ * GNU General Public License for more details.
*
- * You should have received a copy of the GNU Lesser General Public
- * License along with PetaScope. If not, see <http://www.gnu.org/licenses/>.
+ * You should have received a copy of the GNU General Public License
+ * along with rasdaman community. If not, see <http://www.gnu.org/licenses/>.
*
- * For more information please see <http://www.PetaScope.org>
- * or contact Peter Baumann via <baumann@rasdaman.com>.
+ * Copyright 2003, 2004, 2005, 2006, 2007, 2008, 2009 Peter Baumann /
+ rasdaman GmbH.
*
- * Copyright 2009 Jacobs University Bremen, Peter Baumann.
+ * For more information please see <http://www.rasdaman.org>
+ * or contact Peter Baumann via <baumann@rasdaman.com>.
*/
package petascope.wcs.server.exceptions;
@@ -1,23 +1,24 @@
*
- * PetaScope is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License as
- * published by the Free Software Foundation, either version 3 of
- * the License, or (at your option) any later version.
+ * Rasdaman community is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
*
@@ -1,23 +1,24 @@
*
- * PetaScope is distributed in the hope that it will be useful,
+ * Rasdaman community is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
diff --git a/petascope/src/petascope/wcs/server/exceptions/UnsupportedCombinationException.java b/petascope/src/petascope/wcs/server/exceptions/UnsupportedCombinationException.java
index 934fb47..d9c388e 100644
--- a/petascope/src/petascope/wcs/server/exceptions/UnsupportedCombinationException.java
+++ b/petascope/src/petascope/wcs/server/exceptions/UnsupportedCombinationException.java
@@ -1,23 +1,24 @@
/*
- * This file is part of PetaScope.
+ * This file is part of rasdaman community.
*
* PetaScope is free software: you can redistribute it and/or modify
* it under the terms of the GNU Lesser General Public License as
* published by the Free Software Foundation, either version 3 of
* the License, or (at your option) any later version.
*
* PetaScope is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU Lesser General Public License for more details.
+ * GNU General Public License for more details.
*
- * You should have received a copy of the GNU Lesser General Public
- * License along with PetaScope. If not, see <http://www.gnu.org/licenses/>.
+ * You should have received a copy of the GNU General Public License
+ * along with rasdaman community. If not, see <http://www.gnu.org/licenses/>.
*
- * For more information please see <http://www.PetaScope.org>
- * or contact Peter Baumann via <baumann@rasdaman.com>.
+ * Copyright 2003, 2004, 2005, 2006, 2007, 2008, 2009 Peter Baumann /
+ rasdaman GmbH.
*
- * Copyright 2009 Jacobs University Bremen, Peter Baumann.
+ * For more information please see <http://www.rasdaman.org>
+ * or contact Peter Baumann via <baumann@rasdaman.com>.
*/
package petascope.wcs.server.exceptions;
@@ -1,23 +1,24 @@
*
- * PetaScope is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License as
- * published by the Free Software Foundation, either version 3 of
- * the License, or (at your option) any later version.
+ * Rasdaman community is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
*
@@ -1,23 +1,24 @@
*
- * PetaScope is distributed in the hope that it will be useful,
+ * Rasdaman community is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
diff --git a/petascope/src/petascope/wcs/server/exceptions/WCSException.java b/petascope/src/petascope/wcs/server/exceptions/WCSException.java
index 556cf03..14e957a 100644
--- a/petascope/src/petascope/wcs/server/exceptions/WCSException.java
+++ b/petascope/src/petascope/wcs/server/exceptions/WCSException.java
@@ -1,23 +1,24 @@
/*
- * This file is part of PetaScope.
+ * This file is part of rasdaman community.
*
* PetaScope is free software: you can redistribute it and/or modify
* it under the terms of the GNU Lesser General Public License as
* published by the Free Software Foundation, either version 3 of
* the License, or (at your option) any later version.
*
* PetaScope is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU Lesser General Public License for more details.
+ * GNU General Public License for more details.
*
- * You should have received a copy of the GNU Lesser General Public
- * License along with PetaScope. If not, see <http://www.gnu.org/licenses/>.
+ * You should have received a copy of the GNU General Public License
+ * along with rasdaman community. If not, see <http://www.gnu.org/licenses/>.
*
- * For more information please see <http://www.PetaScope.org>
- * or contact Peter Baumann via <baumann@rasdaman.com>.
+ * Copyright 2003, 2004, 2005, 2006, 2007, 2008, 2009 Peter Baumann /
+ rasdaman GmbH.
*
- * Copyright 2009 Jacobs University Bremen, Peter Baumann.
+ * For more information please see <http://www.rasdaman.org>
+ * or contact Peter Baumann via <baumann@rasdaman.com>.
*/
@@ -1,23 +1,24 @@
*
- * PetaScope is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License as
- * published by the Free Software Foundation, either version 3 of
- * the License, or (at your option) any later version.
+ * Rasdaman community is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
*
@@ -1,23 +1,24 @@
*
- * PetaScope is distributed in the hope that it will be useful,
+ * Rasdaman community is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
diff --git a/petascope/src/petascope/wcs/server/exceptions/WcsRuntimeException.java b/petascope/src/petascope/wcs/server/exceptions/WcsRuntimeException.java
index f1dcde8..4f37277 100644
--- a/petascope/src/petascope/wcs/server/exceptions/WcsRuntimeException.java
+++ b/petascope/src/petascope/wcs/server/exceptions/WcsRuntimeException.java
@@ -1,23 +1,24 @@
/*
- * This file is part of PetaScope.
+ * This file is part of rasdaman community.
*
* PetaScope is free software: you can redistribute it and/or modify
* it under the terms of the GNU Lesser General Public License as
* published by the Free Software Foundation, either version 3 of
* the License, or (at your option) any later version.
*
* PetaScope is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU Lesser General Public License for more details.
+ * GNU General Public License for more details.
*
- * You should have received a copy of the GNU Lesser General Public
- * License along with PetaScope. If not, see <http://www.gnu.org/licenses/>.
+ * You should have received a copy of the GNU General Public License
+ * along with rasdaman community. If not, see <http://www.gnu.org/licenses/>.
*
- * For more information please see <http://www.PetaScope.org>
- * or contact Peter Baumann via <baumann@rasdaman.com>.
+ * Copyright 2003, 2004, 2005, 2006, 2007, 2008, 2009 Peter Baumann /
+ rasdaman GmbH.
*
- * Copyright 2009 Jacobs University Bremen, Peter Baumann.
+ * For more information please see <http://www.rasdaman.org>
+ * or contact Peter Baumann via <baumann@rasdaman.com>.
*/
package petascope.wcs.server.exceptions;
@@ -1,23 +1,24 @@
*
- * PetaScope is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License as
- * published by the Free Software Foundation, either version 3 of
- * the License, or (at your option) any later version.
+ * Rasdaman community is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
*
@@ -1,23 +1,24 @@
*
- * PetaScope is distributed in the hope that it will be useful,
+ * Rasdaman community is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
diff --git a/petascope/src/petascope/wcs/server/exceptions/XmlNotValidException.java b/petascope/src/petascope/wcs/server/exceptions/XmlNotValidException.java
index e9ea6ea..ba49b3a 100644
--- a/petascope/src/petascope/wcs/server/exceptions/XmlNotValidException.java
+++ b/petascope/src/petascope/wcs/server/exceptions/XmlNotValidException.java
@@ -1,23 +1,24 @@
/*
- * This file is part of PetaScope.
+ * This file is part of rasdaman community.
*
* PetaScope is free software: you can redistribute it and/or modify
* it under the terms of the GNU Lesser General Public License as
* published by the Free Software Foundation, either version 3 of
* the License, or (at your option) any later version.
*
* PetaScope is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU Lesser General Public License for more details.
+ * GNU General Public License for more details.
*
- * You should have received a copy of the GNU Lesser General Public
- * License along with PetaScope. If not, see <http://www.gnu.org/licenses/>.
+ * You should have received a copy of the GNU General Public License
+ * along with rasdaman community. If not, see <http://www.gnu.org/licenses/>.
*
- * For more information please see <http://www.PetaScope.org>
- * or contact Peter Baumann via <baumann@rasdaman.com>.
+ * Copyright 2003, 2004, 2005, 2006, 2007, 2008, 2009 Peter Baumann /
+ rasdaman GmbH.
*
- * Copyright 2009 Jacobs University Bremen, Peter Baumann.
+ * For more information please see <http://www.rasdaman.org>
+ * or contact Peter Baumann via <baumann@rasdaman.com>.
*/
package petascope.wcs.server.exceptions;
@@ -1,23 +1,24 @@
*
- * PetaScope is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License as
- * published by the Free Software Foundation, either version 3 of
- * the License, or (at your option) any later version.
+ * Rasdaman community is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
*
@@ -1,23 +1,24 @@
*
- * PetaScope is distributed in the hope that it will be useful,
+ * Rasdaman community is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
diff --git a/petascope/src/petascope/wcs/server/exceptions/XmlStructuresException.java b/petascope/src/petascope/wcs/server/exceptions/XmlStructuresException.java
index 66c244b..6016a51 100644
--- a/petascope/src/petascope/wcs/server/exceptions/XmlStructuresException.java
+++ b/petascope/src/petascope/wcs/server/exceptions/XmlStructuresException.java
@@ -1,23 +1,24 @@
/*
- * This file is part of PetaScope.
+ * This file is part of rasdaman community.
*
* PetaScope is free software: you can redistribute it and/or modify
* it under the terms of the GNU Lesser General Public License as
* published by the Free Software Foundation, either version 3 of
* the License, or (at your option) any later version.
*
* PetaScope is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU Lesser General Public License for more details.
+ * GNU General Public License for more details.
*
- * You should have received a copy of the GNU Lesser General Public
- * License along with PetaScope. If not, see <http://www.gnu.org/licenses/>.
+ * You should have received a copy of the GNU General Public License
+ * along with rasdaman community. If not, see <http://www.gnu.org/licenses/>.
*
- * For more information please see <http://www.PetaScope.org>
- * or contact Peter Baumann via <baumann@rasdaman.com>.
+ * Copyright 2003, 2004, 2005, 2006, 2007, 2008, 2009 Peter Baumann /
+ rasdaman GmbH.
*
- * Copyright 2009 Jacobs University Bremen, Peter Baumann.
+ * For more information please see <http://www.rasdaman.org>
+ * or contact Peter Baumann via <baumann@rasdaman.com>.
*/
package petascope.wcs.server.exceptions;
@@ -1,23 +1,24 @@
*
- * PetaScope is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License as
- * published by the Free Software Foundation, either version 3 of
- * the License, or (at your option) any later version.
+ * Rasdaman community is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
*
@@ -1,23 +1,24 @@
*
- * PetaScope is distributed in the hope that it will be useful,
+ * Rasdaman community is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the